/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.metrics2;

import org.apache.hadoop.classification.InterfaceAudience;
import org.apache.hadoop.classification.InterfaceStability;
import org.apache.hadoop.metrics2.annotation.Metric;

/**
 * Interface to provide immutable metainfo for metrics.
 */
@InterfaceAudience.Public
@InterfaceStability.Evolving
public interface MetricsInfo {
  /**
   * Typically name corresponds to annotation {@link Metric#value()} or
   * the name of the class.
   * @return the name of the metric/tag
   */
  String name();

  /**
   * Typically the description corresponds to annotation {@link Metric#about()}
   * or the name of the class.
   * @return the description of the metric/tag
   */
  String description();
}
